@@ -195,7 +195,7 @@ class Provider(AddressProvider):
         "Vila Nova de Foz Côa", "Vila Nova de Gaia", "Vila Nova de Paiva",
         "Vila Nova de Poiares", "Vila Pouca de Aguiar", "Vila Real",
         "Vila Real de Santo António", "Vila Velha de Ródão", "Vila Verde",
-        "Vila Viçosa", "Vimioso", "Vinhais", "Viseu", "Vizela", "Vouzela"
+        "Vila Viçosa", "Vimioso", "Vinhais", "Viseu", "Vizela", "Vouzela",
     ]
 
     def street_prefix(self):
@@ -210,7 +210,6 @@ class Provider(AddressProvider):
         """
         return self.random_element(self.cities)
 
-
     def distrito(self):
         """
         :example 'Bragança'
